@@ -5,12 +5,12 @@ import re
 from typing import List
 
 # Version string must appear intact for hatch versioning
-__version__ = "5.1.5"
+__version__ = "5.3.0"
 
 # Build up version_info tuple for backwards compatibility
 pattern = r"(?P<major>\d+).(?P<minor>\d+).(?P<patch>\d+)(?P<rest>.*)"
 match = re.match(pattern, __version__)
-assert match is not None
+assert match is not None  # noqa
 parts: List[object] = [int(match[part]) for part in ["major", "minor", "patch"]]
 if match["rest"]:
     parts.append(match["rest"])
